#!/usr/bin/env python
import argparse
import requests
import json
import logging

logging.basicConfig(format='%(asctime)s [%(levelname)s] %(message)s', level=logging.DEBUG)
DEFAULT_ES_URL = 'http://localhost:9200'


def read_es_version(es_url, output_dir):
    resp = requests.get(es_url)
    logging.info('Response = {0}'.format(resp.content))
    doc = json.loads(resp.content, "utf-8")
    version = doc['version']['number']
    logging.info('Version = {0}'.format(version))
    text_file = open(output_dir + "/es_version.txt", "w+")
    text_file.write(version)
    text_file.close()


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('--es-url-override', default=DEFAULT_ES_URL, type=str, required=False, dest="es_url",
                        help="Globally replace the es_url for elasticsearch with a new one")
    parser.add_argument('--output-dir', type=str, required=True, dest="output_dir",
                        help="Output dir to write version file")
    args = parser.parse_args()
    logging.info(args)
    read_es_version(args.es_url, args.output_dir)


if __name__ == "__main__":
    main()